@@ -66,7 +66,7 @@ recurser_void2 (int n)
 
 void *trackpoint;
 
-void
+void __attribute__ ((noinline))
 track (int n)
 {
   char stackpos[1];
