@@ -3,8 +3,8 @@
    message sends (so that proper C/C++ argument conversions may
    take place).  */
 /* { dg-do run } */
-
-#include <objc/Object.h>
+/* { dg-xfail-run-if "Needs OBJC2 ABI" { *-*-darwin* && { lp64 && { ! objc2 } } } { "-fnext-runtime" } { "" } } */
+#include "../objc-obj-c++-shared/Object1.h"
 #include <stdlib.h>
 
 #define CHECK_IF(expr) if(!(expr)) abort()
@@ -30,4 +30,4 @@ int main(void)
 	[foo brokenType: (int)d floatingPoint: d];
 	return 0;
 }
-
+#include "../objc-obj-c++-shared/Object1-implementation.h"
