@@ -1,6 +1,7 @@
 /* Contributed by Nicola Pero - Fri Mar  9 21:35:47 CET 2001 */
-#include <objc/objc.h>
-#include <objc/Object.h>
+
+#include <stdlib.h>
+#import "../../objc-obj-c++-shared/Object1.h"
 
 /* Test defining two protocol, a class adopting both of them, 
    and using an object of type `id <Protocol1, Protocol2>' */ 
@@ -55,4 +56,4 @@ int main (void)
 
   return 0;
 }
-
+#include "../../objc-obj-c++-shared/Object1-implementation.h"
